@@ -11,14 +11,14 @@ def __get_base_url(env):
     }.get(env)
 
 
-def __set_payload(payload):
-    if not payload:
+def __set_message(message):
+    if not message:
         return ''
     else:
-        return payload
+        return message
 
 
-def send_log(alert_id, context, payload=None):
+def send_log(alert_id, context, message=None):
     import traceback
     import requests
     base_url = __get_base_url(context['env'])
@@ -27,7 +27,7 @@ def send_log(alert_id, context, payload=None):
     req_body = {
         "traceback_log": traceback.format_exc(),
         "context": context,
-        "payload": __set_payload(payload)}
+        "message": __set_message(message)}
 
     resp = requests.post(req_url, json=req_body)
     print(resp.text)
